@@ -2,7 +2,9 @@ from collections import OrderedDict
 from typing import Optional, Sequence, List, Dict, Any
 from django.conf import settings
 from django.contrib import admin
+from django.contrib.auth import get_user_model
 from django.contrib.auth.models import User
+from django.db.models import QuerySet
 from django.http import HttpRequest
 from django.urls import reverse, resolve
 from django.utils.html import format_html
@@ -18,6 +20,16 @@ from django.utils.encoding import force_str
 from django.contrib.admin.models import LogEntry
 
 
+def get_admin_log(instance: object) -> QuerySet:
+    """
+    Returns admin log (LogEntry QuerySet) of the object.
+    """
+    return LogEntry.objects.filter(
+        content_type_id=get_content_type_for_model(instance).pk,  # type: ignore
+        object_id=instance.pk,  # type: ignore  # pytype: disable=attribute-error
+    )
+
+
 def admin_log(instances: Sequence[object], msg: str, who: Optional[User] = None, **kw):
     """
     Logs an entry to admin logs of model(s).
@@ -30,7 +42,7 @@ def admin_log(instances: Sequence[object], msg: str, who: Optional[User] = None,
     # use system user if 'who' is missing
     if who is None:
         username = settings.DJANGO_SYSTEM_USER if hasattr(settings, "DJANGO_SYSTEM_USER") else "system"
-        who = User.objects.get_or_create(username=username)[0]
+        who = get_user_model().objects.get_or_create(username=username)[0]
 
     # allow passing individual instance
     if not isinstance(instances, list) and not isinstance(instances, tuple):
